'use strict';

var chunk5VRK3JMQ_js = require('./chunk-5VRK3JMQ.js');
var chunkIWNJMGWX_js = require('./chunk-IWNJMGWX.js');
var serialize = require('@emotion/serialize');
var shared = require('@wyw-in-js/shared');
var processorUtils = require('@wyw-in-js/processor-utils');

/**
  * @pigment-css/react v0.0.30
  *
  * @license MIT
  * This source code is licensed under the MIT license found in the
  * LICENSE file in the root directory of this source tree.
  */
 
var KeyframesProcessor = class extends chunkIWNJMGWX_js.BaseProcessor {
  constructor(params, ...args) {
    super([params[0]], ...args);
    if (params.length < 2) {
      throw chunkIWNJMGWX_js.BaseProcessor.SKIP;
    }
    processorUtils.validateParams(
      params,
      ["callee", ["call", "template"]],
      `Invalid use of ${this.tagSource.imported} tag.`
    );
    const [, callParams] = params;
    if (callParams[0] === "call") {
      this.dependencies.push(callParams[1]);
    } else if (callParams[0] === "template") {
      callParams[1].forEach((element) => {
        if ("kind" in element && element.kind !== shared.ValueType.CONST) {
          this.dependencies.push(element);
        }
      });
    }
    this.callParam = callParams;
  }
  build(values) {
    if (this.artifacts.length > 0) {
      throw new Error(`MUI: "${this.tagSource.imported}" is already built`);
    }
    const [callType] = this.callParam;
    if (callType === "template") {
      this.handleTemplate(this.callParam, values);
    } else {
      this.handleCall(this.callParam, values);
    }
  }
  handleTemplate([, callArgs], values) {
    const templateStrs = [];
    templateStrs.raw = [];
    const templateExpressions = [];
    const { themeArgs } = this.options;
    callArgs.forEach((item) => {
      if ("kind" in item) {
        switch (item.kind) {
          case shared.ValueType.FUNCTION: {
            const value = values.get(item.ex.name);
            templateExpressions.push(value(themeArgs));
            break;
          }
          case shared.ValueType.CONST:
            templateExpressions.push(item.value);
            break;
          case shared.ValueType.LAZY: {
            const evaluatedValue = values.get(item.ex.name);
            if (typeof evaluatedValue === "function") {
              templateExpressions.push(evaluatedValue(themeArgs));
            } else {
              templateExpressions.push(evaluatedValue);
            }
            break;
          }
        }
      } else if (item.type === "TemplateElement") {
        templateStrs.push(item.value.cooked);
        templateStrs.raw.push(item.value.raw);
      }
    });
    this.generateArtifacts(templateStrs, ...templateExpressions);
  }
  generateArtifacts(styleObjOrTaggged, ...args) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _i, _j;
    const { styles } = serialize.serializeStyles(
      args.length > 0 ? [styleObjOrTaggged, ...args] : [styleObjOrTaggged],
      chunk5VRK3JMQ_js.cache.registered
    );
    const cssText = `@keyframes {${styles}}`;
    const rules = {
      [this.asSelector]: {
        className: this.className,
        cssText,
        displayName: this.displayName,
        start: (_b = (_a = this.location) == null ? void 0 : _a.start) != null ? _b : null
      }
    };
    const sourceMapReplacements = [
      {
        length: cssText.length,
        original: {
          start: {
            column: (_d = (_c = this.location) == null ? void 0 : _c.start.column) != null ? _d : 0,
            line: (_f = (_e = this.location) == null ? void 0 : _e.start.line) != null ? _f : 0
          },
          end: {
            column: (_h = (_g = this.location) == null ? void 0 : _g.end.column) != null ? _h : 0,
            line: (_j = (_i = this.location) == null ? void 0 : _i.end.line) != null ? _j : 0
          }
        }
      }
    ];
    this.artifacts.push(["css", [rules, sourceMapReplacements]]);
  }
  handleCall([, callArg], values) {
    if (callArg.kind === shared.ValueType.LAZY || callArg.kind === shared.ValueType.FUNCTION) {
      const value = values.get(callArg.ex.name);
      const { themeArgs } = this.options;
      const styleObj = typeof value === "function" ? value(themeArgs) : value;
      if (styleObj) {
        this.generateArtifacts(styleObj);
      }
    }
  }
  doEvaltimeReplacement() {
    this.replacer(this.value, false);
  }
  doRuntimeReplacement() {
    this.doEvaltimeReplacement();
  }
  get asSelector() {
    return this.className;
  }
  get value() {
    return this.astService.stringLiteral(this.className);
  }
};

exports.KeyframesProcessor = KeyframesProcessor;
//# sourceMappingURL=keyframes.js.map
//# sourceMappingURL=keyframes.js.map